
# jpmedical
Python Package。  
Python Package for visualization of total of Health expenditures if people all over the world are Japnanese.


## Example of use
```
pip install jpmedical
python jpmedical.py
```



**output**  
  
1-10 Percentage of users cleared there.  
x Percentage of users who could not clear.
